pilas.fisica.FisicaDeshabilitada

Package pilas :: Module fisica :: Class FisicaDeshabilitada |
[hide private]
[frames] | no frames]

# Class FisicaDeshabilitada

source code

    object --+
             |
            FisicaDeshabilitada

Representa a un motor de física que no realiza acciones, y solo se habilita si box2d no funciona en el equipo.

Instance Methods | [hide private]
__init__(self, area, gravedad=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
actualizar(self) | source code
crear_bordes_del_escenario(self) | source code
reiniciar(self) | source code
capturar_figura_con_el_mouse(self, figura) | source code
cuando_mueve_el_mouse(self, x, y) | source code
cuando_suelta_el_mouse(self) | source code
pausar_mundo(self) | source code
reanudar_mundo(self) | source code
dibujar_figuras_sobre_lienzo(self, motor, lienzo, grosor=1) | source code
crear_cuerpo(self, definicion_de_cuerpo) | source code
crear_suelo(self, (ancho, alto), restitucion=0) | source code
crear_techo(self, (ancho, alto), restitucion=0) | source code
crear_paredes(self, (ancho, alto), restitucion=0) | source code
eliminar_suelo(self) | source code
eliminar_techo(self) | source code
eliminar_paredes(self) | source code
obtener_distancia_al_suelo(self, x, y, dy) | source code
eliminar_figura(self, figura) | source code
obtener_cuerpos_en(self, x, y) | source code
definir_gravedad(self, x, y) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, area, gravedad=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)